==> xorg-server_1.10.4.orig.tar.gz: xorg-server-1.10.4/hw/xwin/winresource.h <==
#if !defined(WINRESOURCE_H)
#define WINRESOURCE_H
/*
 *Copyright (C) 2002-2004 Harold L Hunt II All Rights Reserved.
 *
 *Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 *"Software"), to deal in the Software without restriction, including
 *without limitation the rights to use, copy, modify, merge, publish,
 *distribute, sublicense, and/or sell copies of the Software, and to
 *permit persons to whom the Software is furnished to do so, subject to
 *the following conditions:
 *
 *The above copyright notice and this permission notice shall be
 *included in all copies or substantial portions of the Software.
 *
 *THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 *EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 *MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 *NONINFRINGEMENT. IN NO EVENT SHALL HAROLD L HUNT II BE LIABLE FOR
 *ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
 *CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 *WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 *Except as contained in this notice, the name of Harold L Hunt II
 *shall not be used in advertising or otherwise to promote the sale, use
 *or other dealings in this Software without prior written authorization
 *from Harold L Hunt II.
 *
 * Authors:	Harold L Hunt II
 */


/*
 * Local defines
 */

#define IDC_STATIC		-1
#define IDI_XWIN		101
#define IDM_TRAYICON_MENU	103
#define IDC_CLIENTS_CONNECTED	104


#define ID_APP_EXIT		200
#define ID_APP_HIDE_ROOT	201
#define ID_APP_ALWAYS_ON_TOP	202
#define ID_APP_ABOUT		203

#define ID_ABOUT_UG		300
#define ID_ABOUT_FAQ		301
#define ID_ABOUT_CHANGELOG	302
#define ID_ABOUT_WEBSITE	303

#endif

==> xorg-server_21.1.18.orig.tar.gz: xorg-server-21.1.18/hw/xwin/winresource.h <==
#if !defined(WINRESOURCE_H)
#define WINRESOURCE_H
/*
 *Copyright (C) 2002-2004 Harold L Hunt II All Rights Reserved.
 *
 *Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 *"Software"), to deal in the Software without restriction, including
 *without limitation the rights to use, copy, modify, merge, publish,
 *distribute, sublicense, and/or sell copies of the Software, and to
 *permit persons to whom the Software is furnished to do so, subject to
 *the following conditions:
 *
 *The above copyright notice and this permission notice shall be
 *included in all copies or substantial portions of the Software.
 *
 *THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 *EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 *MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 *NONINFRINGEMENT. IN NO EVENT SHALL HAROLD L HUNT II BE LIABLE FOR
 *ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
 *CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 *WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 *Except as contained in this notice, the name of Harold L Hunt II
 *shall not be used in advertising or otherwise to promote the sale, use
 *or other dealings in this Software without prior written authorization
 *from Harold L Hunt II.
 *
 * Authors:	Harold L Hunt II
 */

/*
 * Local defines
 */

#define IDC_STATIC		-1
#define IDI_XWIN		101
#define IDM_TRAYICON_MENU	103
#define IDC_CLIENTS_CONNECTED	104

#define ID_APP_EXIT		200
#define ID_APP_HIDE_ROOT	201
#define ID_APP_ALWAYS_ON_TOP	202
#define ID_APP_ABOUT		203
#define ID_APP_MONITOR_PRIMARY	204

#define ID_ABOUT_WEBSITE	303

#endif
